@@ -20,12 +20,15 @@
 //! | -------- | ----------- |
 //! | [azblob][crate::services::azblob] | Azure Storage Blob services. |
 //! | [fs][crate::services::fs] | POSIX alike file system. |
+//! | [hdfs][crate::services::hdfs] | Hadoop Distributed File System(HDFS). |
 //! | [memory][crate::services::memory] | In memory backend support. |
 //! | [s3][crate::services::s3] | AWS S3 alike services. |
 //!
 //! # Optional features
 //!
 //! - `compress`: Enable object decompress read support.
+//! - `retry`: Enable operator retry support.
+//! - `services-hdfs`: Enable hdfs service support.
 //!
 //! # Example
 //!
@@ -33,11 +36,11 @@
 //! use anyhow::Result;
 //! use futures::StreamExt;
 //! use opendal::services::fs;
-//! use opendal::ObjectMode;
-//! use opendal::Operator;
 //! use opendal::Metadata;
 //! use opendal::Object;
+//! use opendal::ObjectMode;
 //! use opendal::ObjectStreamer;
+//! use opendal::Operator;
 //!
 //! #[tokio::main]
 //! async fn main() -> Result<()> {
@@ -89,8 +92,8 @@ pub use io::BytesStream;
 pub use io::BytesWrite;
 pub use io::BytesWriter;
 
-mod layer;
-pub use layer::Layer;
+mod layers;
+pub use layers::Layer;
 
 mod operator;
 pub use operator::Operator;
@@ -114,6 +117,3 @@ pub mod services;
 //
 // Please don't export any type from this module.
 mod error;
-
-#[deprecated]
-pub mod readers;
