@@ -21,5 +21,7 @@
 
 pub mod azblob;
 pub mod fs;
+#[cfg(feature = "services-hdfs")]
+pub mod hdfs;
 pub mod memory;
 pub mod s3;
