@@ -949,11 +949,12 @@ impl Accessor for Backend {
             _ => Err(parse_error_response_with_body(resp, "stat", &p).await),
         }
     }
+
     #[trace("delete")]
     async fn delete(&self, args: &OpDelete) -> Result<()> {
         increment_counter!("opendal_s3_delete_requests");
 
-        let p = self.get_abs_path(&args.path);
+        let p = self.get_abs_path(args.path());
         debug!("object {} delete start", &p);
 
         let resp = self.delete_object(&p).await?;
@@ -966,11 +967,12 @@ impl Accessor for Backend {
             _ => Err(parse_error_response_with_body(resp, "delete", &p).await),
         }
     }
+
     #[trace("list")]
     async fn list(&self, args: &OpList) -> Result<ObjectStreamer> {
         increment_counter!("opendal_s3_list_requests");
 
-        let mut path = self.get_abs_path(&args.path);
+        let mut path = self.get_abs_path(args.path());
         // Make sure list path is endswith '/'
         if !path.ends_with('/') && !path.is_empty() {
             path.push('/')
@@ -1182,6 +1184,10 @@ fn parse_error_response_without_body(resp: Response<Body>, op: &'static str, pat
     let kind = match part.status {
         StatusCode::NOT_FOUND => ErrorKind::NotFound,
         StatusCode::FORBIDDEN => ErrorKind::PermissionDenied,
+        StatusCode::INTERNAL_SERVER_ERROR
+        | StatusCode::BAD_GATEWAY
+        | StatusCode::SERVICE_UNAVAILABLE
+        | StatusCode::GATEWAY_TIMEOUT => ErrorKind::Interrupted,
         _ => ErrorKind::Other,
     };
 
@@ -1201,6 +1207,10 @@ async fn parse_error_response_with_body(
     let kind = match part.status {
         StatusCode::NOT_FOUND => ErrorKind::NotFound,
         StatusCode::FORBIDDEN => ErrorKind::PermissionDenied,
+        StatusCode::INTERNAL_SERVER_ERROR
+        | StatusCode::BAD_GATEWAY
+        | StatusCode::SERVICE_UNAVAILABLE
+        | StatusCode::GATEWAY_TIMEOUT => ErrorKind::Interrupted,
         _ => ErrorKind::Other,
     };
 
