@@ -25,9 +25,9 @@ use std::io;
 use anyhow::Result;
 use futures::StreamExt;
 use log::debug;
+use opendal::services;
 use opendal::ObjectMode;
 use opendal::Operator;
-use opendal_test::services;
 use sha2::Digest;
 use sha2::Sha256;
 
@@ -90,8 +90,9 @@ macro_rules! behavior_test {
                     )*
                     async fn [< $test >]() -> Result<()> {
                         init_logger();
+                        let _ = dotenv::dotenv();
 
-                        let acc = super::services::$service::new().await?;
+                        let acc = super::services::$service::tests::new().await?;
                         if acc.is_none() {
                             return Ok(())
                         }
@@ -105,6 +106,12 @@ macro_rules! behavior_test {
 
 behavior_tests!(azblob, fs, memory, s3);
 
+cfg_if::cfg_if! {
+    if #[cfg(feature = "services-hdfs")] {
+        behavior_tests!(hdfs);
+    }
+}
+
 /// Create file with file path should succeed.
 async fn test_create_file(op: Operator) -> Result<()> {
     let path = uuid::Uuid::new_v4().to_string();
